@@ -12,12 +12,12 @@ visited?-proc	=g  getuid	>g  getgid	?g  
 stat:perms	@g  stat:uid	Ag  stat:gid	Bg  stat-dir-readable?-proc	Cg  memq	Dg  depth	Eg  directory-processed	Fg  	directory	Gg  
 nftw-style	Hg  
 stale-symlink	Ig  symlink	Jg  physical	Kg  catch	LK 	MK 	Ng  lstat	Og  	stat:type	Pg  stat	Qg  directory-not-readable	Rg  regular	Sg  invalid-stat	Tg  stat&flag-proc	Ug  clean	Vg  	hash-size	Wg  throw	Xg  ftw-early-exit	Yg  for-each	Zg  getcwd	[g  mount	\g  chdir	]g  nftw-early-exit	^g  make-syntax-transformer	_^ 	`^ 	ag  errno-if-exception	bg  macro	cg  $sc-dispatch	dc 	ec 	fg  any	gff 	hg  
-syntax-object	ig  top	ji 	kg  ribcage	lg  dummy	mg  expr	nlm 	og  m-jUX$eekSAsetxkI3OvNonN-3479	poi 	qpj 	rf  l-jUX$eekSAsetxkI3OvNonN-3484	sf  l-jUX$eekSAsetxkI3OvNonN-3485	trs 	uknqt 	vk 	wg  x	xw 	yp 	zf  l-jUX$eekSAsetxkI3OvNonN-3481	{z 	|kxy{ 	}juv| 	~g  hygiene	~  hK}  g  quote h}  g  system-error h}    g  lambda h}  g  args h}  g  system-error-errno h}        g  syntax-violation     f  -source expression failed to match any pattern g  integer? g  vhash-assoc g  
+syntax-object	ig  top	ji 	kg  ribcage	lg  dummy	mg  expr	nlm 	og  m-ej719fzwV0f04jHhcdUaRe-3674	poi 	qpj 	rf  l-ej719fzwV0f04jHhcdUaRe-3679	sf  l-ej719fzwV0f04jHhcdUaRe-3680	trs 	uknqt 	vk 	wg  x	xw 	yp 	zf  l-ej719fzwV0f04jHhcdUaRe-3676	{z 	|kxy{ 	}juv| 	~g  hygiene	~  hK}  g  quote h}  g  system-error h}    g  lambda h}  g  args h}  g  system-error-errno h}        g  syntax-violation     f  -source expression failed to match any pattern g  integer? g  vhash-assoc g  
 vhash-cons g  directory-stream? g  fold g  cons g  
 alist-cons g  
 vlist-null g  basename g  error 
   
-  f  no matching pattern   g  const g  and=> g  sortC 5      h L     ]4	
+  f  no matching pattern   g  const g  and=> g  sortC 5      hK     ]4	
 "5	 4% >  "  G   &'()*+,      h   s  ]!4 5"  `45$  4>  "  G  C4545$  "  	45$  "  "45" k      g  dir
 		 g  
 dir-stream			 g  new			o g  acc			o g  t		?	X  g  filenamef  
@@ -65,18 +65,22 @@ ice-9/ftw.scm
 	 	 			  g  nameg  stat-dir-readable?-proc CBRCDEFGHIJMN       h   J   ] L 6B       g  filenamef  
 ice-9/ftw.scm
 			# 		
-   C    h   d   - 1 3 C     \       g  k
-			 g  args			  g  filenamef  
+   C    h   V   -  1  3 C     N       g  args
+			  g  filenamef  
 ice-9/ftw.scm
-	 			
-   CIOP  h   J   ] L 6B       g  filenamef  
+	 			
+
+
+   CIOP        h   J   ] L 6B       g  filenamef  
 ice-9/ftw.scm
 			3 		
-   C    h   d   - 1 3 C     \       g  k
-			 g  args			  g  filenamef  
+   C    h   V   -  1  3 C     N       g  args
+			  g  filenamef  
 ice-9/ftw.scm
-	 			
-   CFQRS h     ]4 O 5$  45&  Z4 O 5$  =L$  D45&  4L5$  L"  	"  
+	 			
+
+
+   CFQRS       h     ]4 O 5$  45&  Z4 O 5$  =L$  D45&  4L5$  L"  	"  
 DL D45&  4L5$  L"  	"  
 DD       g  name
 	  g  s	  g  s-follow		5  g  type		R	x g  type	    g  filenamef  
@@ -131,11 +135,13 @@ ice-9/ftw.scm
 	  g  nameg  ftw CRZMN    h   J   ] L 6B       g  filenamef  
 ice-9/ftw.scm
 F		F	, 		
-   C    h   d   - 1 3 C     \       g  k
-			 g  args			  g  filenamef  
+   C    h   V   -  1  3 C     N       g  args
+			  g  filenamef  
 ice-9/ftw.scm
-F	 			
-   C9C[9        h   c   ]4 5L C   [       g  s
+F	 			
+
+
+   C9C[9      h   c   ]4 5L C   [       g  s
 		
   g  filenamef  
 ice-9/ftw.scm
@@ -192,23 +198,21 @@ ice-9/ftw.scm
 5$  4 5$  "  
 O "  4
 5$  O "  45445		$  	"   	5	$  "  
-4445 45 5?O 	
+4445 45 5?O 	
 	Q 4 O 5
 4 >  "  G  
-C      g  filename
-		H g  proc		H g  
-control-flags			H g  od		H g  s			7 g  odev		7H g  	same-dev?		SH g  maybe-cd	 H g  
-maybe-cd-back	 H g  depth-first?	 H g  t		   g  visited?		 H g  	has-kids?	
- H g  	stat&flag	 H g  go	
-H g  ret	
-1H  g  filenamef  
+C       g  filename
+		G g  proc		G g  
+control-flags			G g  od		G g  s			7 g  odev		7G g  	same-dev?		SG g  maybe-cd	 G g  
+maybe-cd-back	 G g  depth-first?	 G g  t		   g  visited?		 G g  	has-kids?	
+ G g  	stat&flag	 G g  go		G g  ret	
+0G  g  filenamef  
 ice-9/ftw.scm
 D
 	
 E	
-	E		F		F		'G		(G		7E		:H		>H		BH		FH		SE		VL		ZL		^L		bL		cM		mM	 E	 U	 U	" U	 U	 E	 X	 X	 X	 E	 Y	 Z	 Z	! Z	 Z	 Y	 E	 \	 E	 _	 `	 `	4 `	= `	 a	! a	 _	 E	
-b	 |	$|	1|	1|	4	 6		H	
-	  g  nameg  nftw CR4`abeg       h   ?   ] C    7       g  dummy
+	E		F		F		'G		(G		7E		:H		>H		BH		FH		SE		VL		ZL		^L		bL		cM		mM	 E	 U	 U	" U	 U	 E	 X	 X	 X	 E	 Y	 Z	 Z	! Z	 Z	 Y	 E	 \	 E	 _	 `	 `	4 `	= `	 a	! _	 E		b	|	#|	0|	0|	3	 5		G	
+	  g  nameg  nftw CR4`abeg h   ?   ] C    7       g  dummy
 		 g  expr		  			   C  h(      ]	4 5$  @ 6             g  x
 		" g  tmp		"  g  filenamef  
 ice-9/ftw.scm
@@ -386,12 +390,12 @@ ice-9/ftw.scm	 
  
 7 
 	 
-K
-\(
+;
+L(
 .
-'D
+'gD
 8
-C^
-L
- 	L
+C.
+K
+ 	K
    C6 
\ No newline at end of file
