@@ -1,4 +1,4 @@
-GOOF----LE-8-2.0L      ]< 4  h      ] g  guile	 	g  define-module*	 	 	g  rnrs	g  
+GOOF----LE-4-2.0L      ]< 4  h      ] g  guile	 	g  define-module*	 	 	g  rnrs	g  
 arithmetic	g  fixnums		 	
 g  filenameS	f  rnrs/arithmetic/fixnums.scm	g  pureS	
 g  versionS		 	g  set-current-module	 	 	g  resolve-r6rs-interface	 	 	g  only	g  ash	g  cons*	g  define-inlinable	g  inexact->exact	g  logand	g  logbit?	g  logcount	g  logior	g  lognot	g  logxor	 g  most-positive-fixnum	!g  most-negative-fixnum	"g  object-address	# !" 	$g  call-with-deferred-observers	%$ 	&$ 	'g  module-use-interfaces!	(' 	)' 	*g  current-module	+* 	,* 	-g  ice-9	.g  optargs	/-. 	0g  base	10 	2g  control	32 	4g  bitwise	54 	6g  
@@ -7,13 +7,13 @@ exceptions	98 	:g  lists	;: 	<g  module-export!	=< 
 fxcopy-bit	Gg  
 fxbit-set?	Hg  fxfirst-bit-set	Ig  fxlength	Jg  fxbit-count	Kg  fxif	Lg  fxxor	Mg  fxior	Ng  fxand	Og  fxnot	Pg  	fx*/carry	Qg  	fx-/carry	Rg  	fx+/carry	Sg  fxmod0	Tg  fxdiv0	Ug  fxdiv0-and-mod0	Vg  fxmod	Wg  fxdiv	Xg  
 fxdiv-and-mod	Yg  fx-	Zg  fx*	[g  fx+	\g  fxmin	]g  fxmax	^g  fxeven?	_g  fxodd?	`g  fxnegative?	ag  fxpositive?	bg  fxzero?	cg  fx<=?	dg  fx>=?	eg  fx<?	fg  fx>?	gg  fx=?	hg  greatest-fixnum	ig  least-fixnum	jg  fixnum-width	kg  fixnum?	l?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\]^_`abcdefghijk -	mg  module-re-export!	nm 	om 	pg  module-replace!	qp 	rp 	sg  round	tg  log	ug  % inline-fixnum?-procedure	vg  make-syntax-transformer	wv 	xv 	yg  inline-fixnum?	zg  macro	{g  $sc-dispatch	|{ 	}{ 	~g  _	g  any ~  g  
-syntax-object g  syntax-parameterize g  m-J8SYmKqK26HWdHjcT3I3OL-1371 g  top   g  ribcage g  t-1370     f  l-J8SYmKqK26HWdHjcT3I3OL-1376       g  x   f  l-J8SYmKqK26HWdHjcT3I3OL-1373     g  shift g  	proc-name g  args       f  l-pM2fJ6v@zfyETg33qLIg6N-105075 f  l-pM2fJ6v@zfyETg33qLIg6N-105076     g  name g  formals g  body     f  l-pM2fJ6v@zfyETg33qLIg6N-105066 f  l-pM2fJ6v@zfyETg33qLIg6N-105067 f  l-pM2fJ6v@zfyETg33qLIg6N-105068     g  make-procedure-name g  prefix     f  l-pM2fJ6v@zfyETg33qLIg6N-105054 f  l-pM2fJ6v@zfyETg33qLIg6N-105052       f  l-pM2fJ6v@zfyETg33qLIg6N-105051      
+syntax-object g  syntax-parameterize g  m-bZU3Yzmc9$mNGpcsBViH0R-1508 g  top   g  ribcage g  t-1507     f  l-bZU3Yzmc9$mNGpcsBViH0R-1513       g  x   f  l-bZU3Yzmc9$mNGpcsBViH0R-1510     g  shift g  	proc-name g  args       f  l-ggW8jgzCzKr4AVj9eWOuhk-105795 f  l-ggW8jgzCzKr4AVj9eWOuhk-105796     g  name g  formals g  body     f  l-ggW8jgzCzKr4AVj9eWOuhk-105786 f  l-ggW8jgzCzKr4AVj9eWOuhk-105787 f  l-ggW8jgzCzKr4AVj9eWOuhk-105788     g  make-procedure-name g  prefix     f  l-ggW8jgzCzKr4AVj9eWOuhk-105774 f  l-ggW8jgzCzKr4AVj9eWOuhk-105772       f  l-ggW8jgzCzKr4AVj9eWOuhk-105771      
  g  hygiene       g  private   y  g  identifier-syntax   u        g  lambda   g  obj     g  not   g  =   
     	  "              g  syntax-violation     f  -source expression failed to match any pattern g  identifier?       u  g  
-assert-fixnum g  each-any ތ g  or g  dummy g  arg   g  m-J8SYmKqK26HWdHjcT3I3OL-1379     f  l-J8SYmKqK26HWdHjcT3I3OL-1384 f  l-J8SYmKqK26HWdHjcT3I3OL-1385       f  l-J8SYmKqK26HWdHjcT3I3OL-1381         g  and   g  map     y  g  raise   g  make-assertion-violation         g  for-all g  assert-fixnums g  define-fxop* g  defineg  op g  m-J8SYmKqK26HWdHjcT3I3OL-1389  f  l-J8SYmKqK26HWdHjcT3I3OL-1394	f  l-J8SYmKqK26HWdHjcT3I3OL-1395
-f  l-J8SYmKqK26HWdHjcT3I3OL-1396	
+assert-fixnum g  each-any ތ g  or g  dummy g  arg   g  m-bZU3Yzmc9$mNGpcsBViH0R-1516     f  l-bZU3Yzmc9$mNGpcsBViH0R-1521 f  l-bZU3Yzmc9$mNGpcsBViH0R-1522       f  l-bZU3Yzmc9$mNGpcsBViH0R-1518         g  and   g  map     y  g  raise   g  make-assertion-violation         g  for-all g  assert-fixnums g  define-fxop* g  defineg  op g  m-bZU3Yzmc9$mNGpcsBViH0R-1526  f  l-bZU3Yzmc9$mNGpcsBViH0R-1531	f  l-bZU3Yzmc9$mNGpcsBViH0R-1532
+f  l-bZU3Yzmc9$mNGpcsBViH0R-1533	
   
- f  l-J8SYmKqK26HWdHjcT3I3OL-1391 
+ f  l-bZU3Yzmc9$mNGpcsBViH0R-1528 
    g  case-lambda  g  y       g  apply   !g  >"g  <#g  >=$g  <=%g  zero?&g  	positive?'g  	negative?(g  odd?)g  even?*g  max+g  min,g  )make-implementation-restriction-violation-g  div.g  mod/g  div-and-mod0g  div01g  mod02g  
 div0-and-mod03g  expt4g  
 bitwise-if5g  bitwise-length6g  bitwise-first-bit-set7g  bitwise-copy-bit8g  bitwise-bit-field9g  bitwise-copy-bit-field:g  bitwise-rotate-bit-field;g  bitwise-reverse-bit-fieldC 5 h2    ]4	
@@ -62,14 +62,14 @@ bitwise-if5g  bitwise-length6g  bitwise-first-bit-set7g  bitwise-cop
 	h	 		  g  nameg  fixnum? CkR"   h      ]
 	4 5C       g  obj
 		  g  filenamef  rnrs/arithmetic/fixnums.scm
-	k	 		  g  nameg  % inline-fixnum?-procedure CuR4xyz}    h   .   ]  C      &       g  t-1370
+	k	 		  g  nameg  % inline-fixnum?-procedure CuR4xyz}    h   .   ]  C      &       g  t-1507
 		
   		
    C~      h   O   ] L 6G       g  filenamef  rnrs/arithmetic/fixnums.scm		k	 		
    C   h      ] C          		
    C 	   hX      ]4 5$  @4 5"  	 6$  4 O ?$  @""   w       g  x
 		U g  tmp		U g  tmp		"	U  g  filenamef  rnrs/arithmetic/fixnums.scm
-	k	 		U   C5yR4xz}   h   0   ]  C      (       g  tmp-1388
+	k	 		U   C5yR4xz}   h   0   ]  C      (       g  tmp-1525
 		
   		
    C   h   >   ]45C   6       g  dummy
