@@ -29,7 +29,7 @@
   (define (sym? x) (symbol? (syntax->datum x)))
 
   (syntax-case import-spec (library only except prefix rename srfi)
-    ;; (srfi :n ...) -> (srfi srfi-n)
+    ;; (srfi :n ...) -> (srfi srfi-n ...)
     ((library (srfi colon-n rest ... (version ...)))
      (and (and-map sym? #'(srfi rest ...))
           (symbol? (syntax->datum #'colon-n))
@@ -40,7 +40,13 @@
                      (substring (symbol->string (syntax->datum #'colon-n))
                                 1)))))
        (resolve-r6rs-interface
-        #`(library (srfi #,srfi-n (version ...))))))
+        (syntax-case #'(rest ...) ()
+          (()
+           #`(library (srfi #,srfi-n (version ...))))
+          ((name rest ...)
+           ;; SRFI 97 says that the first identifier after the colon-n
+           ;; is used for the libraries name, so it must be ignored.
+           #`(library (srfi #,srfi-n rest ... (version ...))))))))
     
     ((library (name name* ... (version ...)))
      (and-map sym? #'(name name* ...))
